<?php

class AitCommentsExtension
{

	public static $paths;
	public static $config;
	public static $network;
	public static $instance;

	public function run($pluginFile) {

		$basedir = dirname($pluginFile);
		$baseurl = plugins_url('', $pluginFile);
		$basename = plugin_basename($pluginFile);
		self::$paths = (object) array(
			'dir' => (object) array(
				'basename'		=> 	$basename,
				'root'       	=> 	$basedir,
				'config'		=>	$basedir . '/config',
				'design'       	=> 	$basedir . '/design',
				'js'	       	=> 	$basedir . '/design/js',
				'css'       	=> 	$basedir . '/design/css',
				'plugin'		=>	$basedir . '/plugin',

			),
			'url' => (object) array(
				'root'     	=> $baseurl,
				'js'     	=> $baseurl . '/design/js',
				'css'      	=> $baseurl . '/design/css',
			),
		);
				
		if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
		    require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
		}
		self::$network =  is_plugin_active_for_network(self::$paths->dir->basename);
				
		spl_autoload_register(array(__CLASS__, 'autoload'));
		add_action( 'plugins_loaded', array(__CLASS__, 'onPluginsLoaded') );

	}

	public static function onPluginsLoaded() {

		load_plugin_textdomain('ait-comments-extension', false, basename(self::$paths->dir->root) . '/languages');
		
		self::loadConfig();

		if(is_admin()){
			//check if plugin is active in network or for single site installation
			$hook = self::$network ? 'network_admin_menu' : 'admin_menu';
			add_action($hook, array(__CLASS__, 'addOptionsPage'));
			add_action('admin_init', array(__CLASS__, 'registerSettings'));
		}		

		add_filter( 'body_class', array(__CLASS__, 'bodyHtmlClass') );
		add_action( 'wp_head', array(__CLASS__, 'enqueueFrontendCss') );
		add_action( 'wp_enqueue_scripts', array(__CLASS__, 'enqueueDesign') );
		add_action( 'admin_enqueue_scripts', array(__CLASS__, 'enqueueAdminDesign') );

		add_filter( 'comment_form_defaults', array(__CLASS__, 'modifyCommentsFields'), 10, 1 );
	}

	public static function loadConfig(){
		self::$config = include self::$paths->dir->config .'/config.php';
	}

	public static function modifyCommentsFields($defaults) {

		$options = AitCommentsExtension::getOptions();
		$commenter = wp_get_current_commenter();
		$req = get_option( 'require_name_email' );
		$aria_req = ( $req ? " aria-required='true'" : '' );
		$html_req = ( $req ? " required='required'" : '' );
		$fieldsData = array(
			'author' 		=>  array(
									"helper" 		=> AitCommentsExtension::aitGetText($options["textNameField"]),
									"label" 		=> AitCommentsExtension::aitGetText($options["textNameLabel"]),
									"html"			=> '<p class="comment-form-author"><label for="author">' . AitCommentsExtension::aitGetText($options["textNameLabel"]) .
													    ( $req ? '<span class="required"> *</span>' : '' ) . '</label>' .
													    '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
													    '" size="30"' . $aria_req . $html_req . ' /></p>',
								),
			'email' 		=>  array(
									"helper"		=> AitCommentsExtension::aitGetText($options["textEmailField"]),
									"label" 		=> AitCommentsExtension::aitGetText($options["textEmailLabel"]),
									"html"			=> '<p class="comment-form-email"><label for="email">' . AitCommentsExtension::aitGetText($options["textEmailLabel"]) .
													    ( $req ? '<span class="required"> *</span>' : '' ) . '</label>' .
													    '<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
													    '" size="30"' . $aria_req . $html_req . ' /></p>',
								),
			'url' 			=>  array(
									"helper"		=> AitCommentsExtension::aitGetText($options["textWebsiteField"]),
									"label" 		=> AitCommentsExtension::aitGetText($options["textWebsiteLabel"]),
									"html"			=> '<p class="comment-form-url"><label for="url">' . AitCommentsExtension::aitGetText($options["textWebsiteLabel"]) . '</label>' .
													    '<input id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) .
													    '" size="30" /></p>',
												    
								),
			'comment_field'	=>  array(
									"helper"		=> AitCommentsExtension::aitGetText($options["textCommentField"]),
									"label" 		=> AitCommentsExtension::aitGetText($options["textCommentLabel"]),
									"html"			=> '<p class="comment-form-comment"><label for="comment">' . AitCommentsExtension::aitGetText($options["textCommentLabel"]) .
													    '</label><textarea id="comment" name="comment" cols="45" rows="8" aria-required="true">' .
													    '</textarea></p>',
								),
		);

		foreach ($fieldsData as $fieldName => $fieldData) {
				$fieldText = $fieldData['helper'];
				$fieldLabel = $fieldData['label'];
				$fieldDefaultHtml = $fieldData['html'];
				//check if default field was not removed by third-paty plugin
				if (!AitCommentsExtension::checkDefaultField($defaults, $fieldName)) continue; 

				//check if is active exception theme where Name and Email fields are changed in theme action in functions.php
				//exception themes: Directory+, BusinessFinder+
				if(AitCommentsExtension::isExceptionTheme()){
					//do not change name and email fields
					if($fieldLabel != "" && ( $fieldName != "author" && $fieldName != "email" ) ){
						//change field in exception theme
						$fieldHtml = $fieldDefaultHtml;	
					}else{
						//left default not changed field structure
						$fieldHtml = ( $fieldName == 'comment_field' ) ? $defaults[$fieldName] : $defaults['fields'][$fieldName];	
					}
				}else{
					//is not active exception theme
					if($fieldLabel != ""){
						//set label from plugin options
						$fieldHtml = $fieldDefaultHtml;
					}else{
						//left default not changed field structure
						$fieldHtml = ( $fieldName == 'comment_field' ) ? $defaults[$fieldName] : $defaults['fields'][$fieldName];
					}			
				}


				//find closing </p> tag used in default wordpress comments structure, if not found, form was probably modified.
				if(strripos($fieldHtml,"</p>")){ 
					$fieldExtension = ($fieldText != "" ) ? '<span class="ait-comments-extension">'.$fieldText.'</span>' : "";
					$fieldHtmlModified = str_ireplace('</p>', $fieldExtension . '</p>', $fieldHtml);

					//modify default values
					if ($fieldName == 'comment_field'){
						$defaults[$fieldName] = $fieldHtmlModified;
					}else{
						$defaults['fields'][$fieldName] = $fieldHtmlModified;
					}
				}
		}
		$defaults['class_form'] = $defaults['class_form'] . ' ait-comments-extension-form';
		//modify class


		return $defaults;
	}
	public static function isExceptionTheme() {
		//AIT Directory+ and BusinessFinder+ themes include own hooks to change comment form and labels
		if( defined('AIT_THEME_ACTIVE_DIRECTORY2') || defined('AIT_THEME_ACTIVE_BUSINESSFINDER2')){
			return true;
		}else{
			return false;
		}
	}
	public static function checkDefaultField( $defaults, $fieldName ){
		$result = false;
		if ($fieldName == 'comment_field'){
			(isset($defaults[$fieldName])) ? $result = true : $result = false;
		}else{
			(isset($defaults['fields'][$fieldName])) ? $result = true : $result = false;
		}
		return $result;
	}

	public static function aitGetText($text){
		$result = '';
		if(class_exists('AitLangs')){
			// ait themes
			$result = AitLangs::getCurrentLocaleText($text);
		} else {
			// 3rd party
			if(is_array($text)){
				// transition from ait theme with ait-langs plugin
				$result = $text['en_US'];
			} else {
				// clean install on 3rd party theme
				$result = $text;
			}
		}
		return $result;
	}

	public static function enqueueDesign(){
		foreach(self::$config['assets']['frontend']['css'] as $asset){
			if($asset['handle'] == "ait-comments-extension-font-fontawesome"){
				if(!class_exists("AitTheme")){
					wp_enqueue_style( $asset['handle'], self::$paths->url->css . '/' . $asset['filename'], $asset['dependencies'], $asset['version'], $asset['media'] );
				}
			} else {
				wp_enqueue_style( $asset['handle'], self::$paths->url->css . '/' .$asset['filename'], $asset['dependencies'], $asset['version'], $asset['media'] );
			}
		}
		foreach(self::$config['assets']['frontend']['js'] as $asset){
			wp_enqueue_script( $asset['handle'], self::$paths->url->js . '/' .$asset['filename'], $asset['dependencies'], $asset['version'], $asset['inFooter'] );
		}
	}

	public static function enqueueAdminDesign(){
		foreach(self::$config['assets']['admin']['css'] as $asset){
				wp_enqueue_style( $asset['handle'], self::$paths->url->css . '/' .$asset['filename'], $asset['dependencies'], $asset['version'], $asset['media'] );
		}
		foreach(self::$config['assets']['admin']['js'] as $asset){
			wp_enqueue_script( $asset['handle'], self::$paths->url->js . '/' .$asset['filename'], $asset['dependencies'], $asset['version'], $asset['inFooter'] );
		}
	}

	public static function enqueueFrontendCss(){
		echo '<style type="text/css">';
		include self::$paths->dir->plugin . '/AitCommentsExtensionCssTemplate.php';
		echo '</style>';
	}

	public static function bodyHtmlClass($classes) {
		$classes[] = 'ait-comments-extension-plugin';
		return $classes;
	}

	public static function addOptionsPage() {

		if(class_exists('AitTheme') && !self::$network){
			
			$page = new AitCommentsExtensionBrandedSettings(self::$instance); //$page == 'AitCommentsExtensionBrandedSettings'
			$hook = add_submenu_page(
				'ait-theme-options',
				__('Comments Extension', 'ait-comments-extension'),
				__('Comments Extension', 'ait-comments-extension'),
				apply_filters('ait-comments-extension-menu-permission', 'manage_options'),
				'ait_comments_extension_options',
				array($page, 'render')
			);

		}else{
			
			$page = new AitCommentsExtensionSimpleSettings(__CLASS__); //$page == 'AitCommentsExtensionSimpleSettings'
			$hook = add_menu_page(
				__('AIT Comments Extension', 'ait-comments-extension'),
				__('AIT Comments Extension', 'ait-comments-extension'),
				apply_filters('ait-comments-extension-menu-permission', 'manage_options'),
				'ait_comments_extension_options',
				array($page, 'render')
			);

		}

		//prepared less for css styles - not used because of possible activation on sites in network (the same colors are applied for all sites)
		//add_action('load-'.$hook, array(__CLASS__, 'adminOptionsOnSave') );			
	}

	public static function adminOptionsOnSave(){
		//not used less compilation for now
		if(isset($_GET['settings-updated']) && $_GET['settings-updated']){
			if(!class_exists('lessc')){
				require( self::$paths->dir->libs .'/lessc.inc.php');
			}
			$parser = new lessc;

			$colors = array();
			$dbOptions = AitCommentsExtension::getOptions();
			foreach(self::$config['admin']['colors']['options'] as $slug => $value){
				$colors[$slug] = $dbOptions[$slug];
			}
			$parser->setVariables($colors);
			@$parser->compileFile(self::$paths->dir->css.'/style.less', self::$paths->dir->css.'/style.css');
		}		
	}

	public static function registerSettings(){
		register_setting(
			'ait_comments_extension_options',
			'ait_comments_extension_options',
			array(__CLASS__, 'validateOptions')
		);

		foreach(self::$config['admin'] as $section => $settings){
			add_settings_section(
				$section,
				$settings['title'],
				'__return_false',
				'ait_comments_extension_options'
			);

			foreach($settings['options'] as $slug => $value){
				$label = ( class_exists("AitTheme") && !self::$network ) ? "" : $value['label'];

				add_settings_field(
					$slug,
					$label,
					array(__CLASS__, 'renderField'),
					'ait_comments_extension_options',
					$section,
					array('slug' => $slug, 'config' => $value)
				);
			}
		}
	}

	public static function validateOptions($input){
		return wp_parse_args($input, AitCommentsExtension::getOptions());
	}

	public static function getOptions($key = ''){
		
		$dbOptions = self::$network ? get_site_option( 'ait_comments_extension_options', array() ) : get_option('ait_comments_extension_options', array());

		$options = wp_parse_args(
			$dbOptions,
			AitCommentsExtension::getDefaultOptions()
		);
		if($key and isset($options[$key])){
			return $options[$key];
		}

		return $options;
	}

	public static function getDefaultOptions(){
		$result = array();

		foreach(self::$config['admin'] as $section => $settings){
			foreach ($settings['options'] as $slug => $value) {
				switch($value['type']){
					case "on-off":
						$result[$slug] = intval((bool)$value['default']);
					break;
					case "select":
						$result[$slug] = $value['selected'];
					break;
					default:
						$result[$slug] = $value['default'];
					break;
				}
			}
		}
		return $result;
	}


	public static function renderField($option){

		if(class_exists("AitTheme")){
			//render branded field
			switch($option['config']['type']){
				case "text":
					echo "<div class='ait-opt-container ait-opt-string-main'>";
						echo "<div class='ait-opt-wrap'>";
							echo "<div class='ait-opt-label'>";
								echo "<div class='ait-label-wrapper'>";
									echo "<span class='ait-label'>".$option['config']['label']."</span>";
								echo "</div>";
								if(!empty($option['config']['help'])) {
									echo "<div class='ait-opt-help'>";
										echo "<div class='ait-help'>";
											echo $option['config']['help'];
										echo "</div>";
									echo "</div>";
								}
							echo "</div>";
							echo "<div class='ait-opt ait-opt-string'>";
								$stored = AitCommentsExtension::getOptions($option['slug']);
								foreach(AitLangs::getLanguagesList() as $lang){
									if(!AitLangs::isFilteredOut($lang)){
										echo '<div class="ait-opt-wrapper '.AitLangs::htmlClass($lang->locale).'">';
											if(AitLangs::isEnabled()){
												echo '<div class="flag">'.$lang->flag.'</div>';
											}
											if( is_array($stored) ){
												$value = isset($stored[$lang->locale]) ? $stored[$lang->locale] : "";
											}else{
												$value = $stored;
											}
											echo '<input type="text" name="ait_comments_extension_options['.$option['slug'].']['.$lang->locale.']" value="'.esc_attr($value).'">';
										echo '</div>';
									} else {
										$value = is_array($stored) ? $stored[$lang->locale] : $stored;
										echo '<input type="hidden" name="ait_comments_extension_options['.$option['slug'].']['.$lang->locale.']" value="'.esc_attr($value).'">';
									}

								}
							echo "</div>";
						echo "</div>";
					echo "</div>";
				break;
				case "textarea":
					echo "<div class='ait-opt-container ait-opt-multiline-code-main'>";
						echo "<div class='ait-opt-wrap'>";
							echo "<div class='ait-opt-label'>";
								echo "<div class='ait-label-wrapper'>";
									echo "<span class='ait-label'>".$option['config']['label']."</span>";
								echo "</div>";
								if(!empty($option['config']['help'])) {
									echo "<div class='ait-opt-help'>";
										echo "<div class='ait-help'>";
											echo $option['config']['help'];
										echo "</div>";
									echo "</div>";
								}
							echo "</div>";
							echo "<div class='ait-opt ait-opt-multiline-code'>";
								echo "<div class='ait-opt-wrapper'>";
									$stored = AitCommentsExtension::getOptions($option['slug']);
									echo '<textarea name="ait_comments_extension_options['.$option['slug'].']" rows="5">'.esc_attr($stored).'</textarea>';
								echo "</div>";
							echo "</div>";
						echo "</div>";
					echo "</div>";
				break;
				case "on-off":
					echo "<div class='ait-opt-container ait-opt-on-off-main'>";
						echo "<div class='ait-opt-wrap'>";
							echo "<div class='ait-opt-label'>";
								echo "<div class='ait-label-wrapper'>";
									echo "<span class='ait-label'>".$option['config']['label']."</span>";
								echo "</div>";
							echo "</div>";
							echo "<div class='ait-opt ait-opt-on-off'>";
								echo "<div class='ait-opt-wrapper'>";
									echo "<div class='ait-opt-switch'>";
										echo '<select name="ait_comments_extension_options['.$option['slug'].']">';
											$stored = AitCommentsExtension::getOptions($option['slug']);
											if(esc_attr($stored) == "1"){
												echo '<option value="1" selected>'.__('On', 'ait-comments-extension').'</option>';
												echo '<option value="0">'.__('Off', 'ait-comments-extension').'</option>';
											} else {
												echo '<option value="1">'.__('On', 'ait-comments-extension').'</option>';
												echo '<option value="0" selected>'.__('Off', 'ait-comments-extension').'</option>';
											}
										echo '</select>';
									echo "</div>";
								echo "</div>";
							echo "</div>";
							if(!empty($option['config']['help'])) {
								echo "<div class='ait-opt-help'>";
									echo "<div class='ait-help'>";
										echo $option['config']['help'];
									echo "</div>";
								echo "</div>";
							}
						echo "</div>";
					echo "</div>";
				break;
				case "color":
					echo "<div class='ait-opt-container ait-opt-color-main'>";
						echo "<div class='ait-opt-wrap'>";
							echo "<div class='ait-opt-label'>";
								echo "<div class='ait-label-wrapper'>";
									echo "<span class='ait-label'>".$option['config']['label']."</span>";
								echo "</div>";
							echo "</div>";
							echo "<div class='ait-opt ait-opt-color'>";
								echo "<div class='ait-opt-wrapper'>";
									echo "<div class='ait-colorpicker ait-control-wrapper'>";
										$stored = AitCommentsExtension::getOptions($option['slug']);
										echo '<span class="ait-colorpicker-preview"><i style="background-color: '.esc_attr($stored).'"></i></span>';
										echo '<input type="text" name="ait_comments_extension_options['.$option['slug'].']" value="'.esc_attr($stored).'" class="ait-colorpicker-color" data-color-format="hex">';
										echo '<span class="ait-unit ait-value">100</span>';
										echo '<span class="ait-unit"> %</span>';
									echo "</div>";
								echo "</div>";
							echo "</div>";
							if(!empty($option['config']['help'])) {
								echo "<div class='ait-opt-help'>";
									echo "<div class='ait-help'>";
										echo $option['config']['help'];
									echo "</div>";
								echo "</div>";
							}
						echo "</div>";
					echo "</div>";
				break;
				case "select":
					echo "<div class='ait-opt-container ait-opt-select-main'>";
						echo "<div class='ait-opt-wrap'>";
							echo "<div class='ait-opt-label'>";
								echo "<div class='ait-label-wrapper'>";
									echo "<span class='ait-label'>".$option['config']['label']."</span>";
								echo "</div>";
								if(!empty($option['config']['help'])) {
									echo "<div class='ait-opt-help'>";
										echo "<div class='ait-help'>";
											echo $option['config']['help'];
										echo "</div>";
									echo "</div>";
								}
							echo "</div>";
							echo "<div class='ait-opt ait-opt-select'>";
								echo "<div class='ait-opt-wrapper chosen-wrapper'>";
									$stored = AitCommentsExtension::getOptions($option['slug']);
									if( is_array($stored) ){
										//get defaults
										$stored = $option['config']['selected'];
									}
									echo '<select name="ait_comments_extension_options['.$option['slug'].']">';
										foreach ( $option['config']['default'] as $defaultSlug => $defaultLabel ) {
												$selected = ($stored == $defaultSlug) ? "selected" : $selected = "";
												echo '<option value="'.$defaultSlug.'" '.$selected.'>'.$defaultLabel.'</option>';
										}
									echo '</select>';
									
								echo "</div>";
							echo "</div>";
						echo "</div>";
					echo "</div>";
				break;
				default:
				break;
			}
		} else {
			//render standard options (no branded AIT options)
			switch($option['config']['type']){
				case "text":
					$stored = AitCommentsExtension::getOptions($option['slug']);
					if(is_array($stored)){
						foreach($stored as $lang => $text){
							if($lang == 'en_US'){
								echo '<input type="text" name="ait_comments_extension_options['.$option['slug'].'][en_US]" value="'.esc_attr($stored['en_US']).'" class="regular-text">';
							} else {
								echo '<input type="hidden" name="ait_comments_extension_options['.$option['slug'].']['.$lang.']" value="'.esc_attr($stored[$lang]).'" class="regular-text">';
							}
						}
					} else {
						echo '<input type="text" name="ait_comments_extension_options['.$option['slug'].']" value="'.esc_attr($stored).'" class="regular-text">';
					}
					if(!empty($option['config']['help'])) {echo '<p class="description">'.$option['config']['help'].'</p>';}
				break;
				case "textarea":
					echo '<textarea name="ait_comments_extension_options['.$option['slug'].']" class="large-text code">'.esc_attr(AitCommentsExtension::getOptions($option['slug'])).'</textarea>';
					if(!empty($option['config']['help'])) {echo '<p class="description">'.$option['config']['help'].'</p>';}
				break;
				case "on-off":
					echo '<select name="ait_comments_extension_options['.$option['slug'].']">';
						if(esc_attr(AitCommentsExtension::getOptions($option['slug'])) == "1"){
							echo '<option value="1" selected>'.__('On', 'ait-comments-extension').'</option>';
							echo '<option value="0">'.__('Off', 'ait-comments-extension').'</option>';
						} else {
							echo '<option value="1">'.__('On', 'ait-comments-extension').'</option>';
							echo '<option value="0" selected>'.__('Off', 'ait-comments-extension').'</option>';
						}
					echo '</select>';
					if(!empty($option['config']['help'])) {echo '<p class="description">'.$option['config']['help'].'</p>';}
				break;
				case "color":
					echo '<input type="text" name="ait_comments_extension_options['.$option['slug'].']" value="'.esc_attr(AitCommentsExtension::getOptions($option['slug'])).'" class="regular-text">';
					if(!empty($option['config']['help'])) {echo '<p class="description">'.$option['config']['help'].'</p>';}
				break;
				case "select":
					$stored = AitCommentsExtension::getOptions($option['slug']);
					if( is_array($stored) ){
						$stored = $option['config']['selected'];
					}
					echo '<select name="ait_comments_extension_options['.$option['slug'].']">';
						foreach ( $option['config']['default'] as $defaultSlug => $defaultLabel ) {
								$selected = ($stored == $defaultSlug) ? "selected" : $selected = "";
								echo '<option value="'.$defaultSlug.'" '.$selected.'>'.$defaultLabel.'</option>';
						}
					echo '</select>';
					
					if(!empty($option['config']['help'])) {echo '<p class="description">'.$option['config']['help'].'</p>';}
				break;
				default:
				break;
			}
		}
	}


	/* ************ helper methods ********** */

	public static function getInstance()
	{
		if(!self::$instance){
			self::$instance = new self;
		}

		return self::$instance;
	}


	public static function autoload($class)
	{
		$file = '';

		if(substr($class, 0, 20) === 'AitCommentsExtension'){
			$file = self::$paths->dir->plugin . "/{$class}.php";
		}

		if($file and file_exists($file)){
			require_once $file;
		}
	}

}