<?php


class AitCommentsExtensionBrandedSettings
{
	protected $commentsExtension;

	public function __construct($commentsExtension) {

		add_action('admin_enqueue_scripts', array($this, 'enqueueAssets'));
		$this->save();
	}

	public function enqueueAssets() {	
		if(isset($_REQUEST['page']) && $_REQUEST['page'] == 'ait_comments_extension_options' ) {
			//AIT theme styles and scripts
			$assetsUrl = aitPaths()->url->admin . '/assets';
			$min = ((defined('SCRIPT_DEBUG') and SCRIPT_DEBUG) or AIT_DEV) ? '' : '.min';
			wp_enqueue_style('jquery-switch', "{$assetsUrl}/libs/jquery-switch/jquery.switch.css", array(), '0.4.1');
			wp_enqueue_style('ait-jquery-chosen', "{$assetsUrl}/libs/chosen/chosen.css", array(), '0.9.10');
			wp_enqueue_style('ait-colorpicker', "{$assetsUrl}/libs/colorpicker/colorpicker.css", array(), '2.2.1');
			wp_enqueue_style('ait-admin-style', "{$assetsUrl}/css/style.css", array(), AIT_THEME_VERSION);
			wp_enqueue_style('ait-admin-options-controls', "{$assetsUrl}/css/options-controls.css", array('ait-admin-style'), AIT_THEME_VERSION);
			
			wp_enqueue_script('ait.admin', "{$assetsUrl}/js/ait.admin.js", array('underscore'), AIT_THEME_VERSION, TRUE);

			wp_enqueue_script('ait-jquery-switch', "{$assetsUrl}/libs/jquery-switch/jquery.switch.min.js", array('jquery', 'ait.admin'), FALSE, TRUE);
			wp_enqueue_script('ait.admin.Tabs', "{$assetsUrl}/js/ait.admin.tabs.js", array('ait.admin', 'jquery'), AIT_THEME_VERSION, TRUE);
			wp_enqueue_script('ait-colorpicker', "{$assetsUrl}/libs/colorpicker/colorpicker{$min}.js", array('jquery'), '2.2.1', TRUE);
			wp_enqueue_script('ait-jquery-chosen', "{$assetsUrl}/libs/chosen/chosen.jquery{$min}.js", array('jquery'), '1.0.0', TRUE);
			wp_enqueue_script('ait.admin.options', "{$assetsUrl}/js/ait.admin.options.js", array('ait.admin', 'jquery', 'jquery-ui-tabs', 'ait-jquery-chosen', 'jquery-ui-datepicker'), AIT_THEME_VERSION, TRUE);

			
			wp_enqueue_style('ait-comments-extension-branded-settings-screen-css', AitCommentsExtension::$paths->url->css . '/admin-branded-screen.css');
		}
	}

	public function save() {
		//save options from branded screen settings
		if(isset($_REQUEST['settings-updated']) && $_REQUEST['settings-updated'] && isset($_REQUEST['page']) && $_REQUEST['page'] == 'ait_comments_extension_options') {
			
			//check if data have to be saved for network site
			//get fist options saved for single site, and then save them for network too, if necessary
			if(AitCommentsExtension::$network){
				$savedData = get_option('ait_comments_extension_options', true);
				update_site_option( 'ait_comments_extension_options', $savedData);
			}else{
				//do nothing, settings were saved for single site
			}

		}
	}


	public function render() {

		?>
		<div class="wrap">

			<div id="ait-comments-extension-page" class="ait-admin-page ait-options-layout">
				<div class="ait-admin-page-wrap">

					<div class="ait-options-page-header">
						<h3 class="ait-options-header-title"><?php printf(_x('%s Settings', 'AIT Comments Extension', 'ait-comments-extension'), 'AIT Comments Extension') ?></h3>
						<div class="ait-options-header-tools">
							<a class="ait-scroll-to-top"><i class="fa dashicons dashicons-arrow-up-alt2" style="line-height: 14px;height: auto;width: auto; font-weight: 700;vertical-align: initial;"></i></a>
							<div class="ait-header-save">
								<button type="submit" name="submit" id="comments-extension-save-options" class="ait-save-comments-extension-settings">
									<?php esc_html_e('Save settings', 'ait-comments-extension') ?>
								</button>

								<div id="action-indicator-save" class="action-indicator action-save"></div>
							</div>
						</div>

						<div class="ait-sticky-header">
							<h4 class="ait-sticky-header-title"><?php printf(_x('%s Settings', 'AIT Comments Extension', 'ait-comments-extension'), 'AIT Comments Extension') ?><i class="fa fa-circle"></i><span class="subtitle"></span></h4>
						</div>
					</div>

					<div class="ait-options-page">

						<div class="ait-options-page-content">

							<div class="ait-options-sidebar">
								<div class="ait-options-sidebar-content">
									<ul id="ait-comments-extension-tabs" class="ait-options-tabs">
										<?php
										foreach(AitCommentsExtension::$config['admin'] as $section => $settings){
											echo '<li id="ait-comments-extension-'.$section.'-panel-tab" class=""><a href="#ait-comments-extension-'.$section.'-panel">'.$settings['title'].'</a></li>';
										}
										?>
									</ul>
								</div>
							</div>

							<div class="ait-options-content">
								<div class="ait-options-controls-container">
									<div id="ait-comments-extension-panels" class="ait-options-controls ait-options-panels">

										<form action="options.php" method="post" id="ait-comments-extension-branding-page-form">
											<?php
												settings_fields('ait_comments_extension_options');
												foreach(AitCommentsExtension::$config['admin'] as $section => $settings){
													echo '<div id="ait-comments-extension-'.$section.'-panel" class="ait-options-group ait-options-panel ait-comments-extension-tabs-panel">';
														echo '<div id="ait-options-basic-'.$section.'" class="ait-controls-tabs-panel ait-options-basic">';
															echo '<div class="ait-options-section ">';
																do_settings_fields( 'ait_comments_extension_options', $section );
															echo '</div>';
														echo '</div>';
													echo '</div>';
												}	
											?>
										</form>

									</div>
								</div>
							</div>

						</div>
					</div>
				</div>
			</div>
		</div>
		<script>
			jQuery(function(){
				new ait.admin.Tabs(jQuery('#ait-comments-extension-tabs'), jQuery('#ait-comments-extension-panels'), 'ait-comments-extension-settings-page');
			})
		</script>
		<?php
	}
}
